'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var store = require('svelte/store');

var setupMq = function (queryString) { return function (set) {
  var query = window.matchMedia(queryString);
  var callback = function (e) { return set(e.matches); };
  query.addListener(callback);
  callback(query);
  return function () { return query.removeListener(callback); }
}; };

var defaultQueries = {
  desktop: 'screen and (min-width: 769px)',
  mobile: 'screen and (max-width: 768px)'
};

var makeMediaStoreInstance = function (queries) {
  var qs = Object.entries(queries).reduce(function (acc, ref) {
    var mediaName = ref[0];
    var queryString = ref[1];

    return (acc[mediaName] = store.readable(false, setupMq(queryString)), acc);
  }, {});
  return store.derived(Object.values(qs), function ($queryStores) { return $queryStores.reduce(function (acc, q, i) { return (acc[Object.keys(qs)[i]] = q, acc); }, {}); })
};
var setup = function (queries) {
if ( queries === void 0 ) queries = defaultQueries;
 exports.media = makeMediaStoreInstance(queries); };
var createMedia = function (queries) {
  if ( queries === void 0 ) queries = defaultQueries;

  return ({ media: makeMediaStoreInstance(queries) });
};

exports.createMedia = createMedia;
exports.setup = setup;
